#include "todolistwidget.h"
#include "todowidget.h"
#include "todotablemodel.h"

ToDoListWidget::ToDoListWidget(TodoManager& m, QWidget *parent)
    : QWidget(parent), manager(m)
{
    todoWidget = 0;
    QVBoxLayout* widgetLayout = new QVBoxLayout();
    // Add table
    todoTableView = new QTableView();
    TodoTableModel* model = new TodoTableModel(manager, 0);
    todoTableView->setModel( model );
    widgetLayout->addWidget(todoTableView);
    // Add buttons
    QHBoxLayout* buttonsLayout = new QHBoxLayout();
    QPushButton* addButton = new QPushButton("Add");
    buttonsLayout->addWidget(addButton);
    editButton = new QPushButton("Edit");
    buttonsLayout->addWidget(editButton);
    widgetLayout->addLayout(buttonsLayout);
    // Set layout
    setLayout(widgetLayout);
    // Handle events
    connect(addButton, SIGNAL(clicked()), this, SLOT(addTodo()));
    connect(editButton, SIGNAL(clicked()), this, SLOT(editTodo()));
    QItemSelectionModel *selectionModel= todoTableView->selectionModel();
    connect(selectionModel, SIGNAL(selectionChanged (const QItemSelection&, const QItemSelection&)),
                this, SLOT(todoSelectionChanged(const QItemSelection&, const QItemSelection&))); }

ToDoListWidget::~ToDoListWidget()
{
}

void ToDoListWidget::addTodo() {
    if (todoWidget == 0) {
        todoWidget = new TodoWidget(manager);
    }
    todoWidget->setTodo(Todo("", ""));
    todoWidget->show();
}

void ToDoListWidget::editTodo() {
    if (todoWidget == 0) {
        todoWidget = new TodoWidget(manager);
    }
    Todo todo = manager.tasks()[todoTableView->currentIndex().row()];
    todoWidget->setTodo(todo);
    todoWidget->show();
}

void ToDoListWidget::todoSelectionChanged(const QItemSelection& newSelection, const QItemSelection& oldSelection) {
    editButton->setEnabled(newSelection.indexes().size() > 0);
}
